@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2012  Oliver Burn
+// Copyright (C) 2001-2014  Oliver Burn
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -57,7 +57,7 @@ import com.puppycrawl.tools.checkstyle.api.TokenTypes;
  *
  * <p>
  * The basic idea behind this is that while
- * pretty printers are sometimes convienent for bulk reformats of
+ * pretty printers are sometimes convenient for bulk reformats of
  * legacy code, they often either aren't configurable enough or
  * just can't anticipate how format should be done.  Sometimes this is
  * personal preference, other times it is practical experience.  In any
@@ -103,6 +103,7 @@ import com.puppycrawl.tools.checkstyle.api.TokenTypes;
  *
  * @author jrichard
  * @author o_sukhodolsky
+ * @author Maikel Steneker
  */
 public class IndentationCheck extends Check
 {
@@ -118,6 +119,9 @@ public class IndentationCheck extends Check
     /** how far brace should be indented when on next line */
     private int mBraceAdjustment;
 
+    /** how far throws should be indented when on next line */
+    private int mThrowsIndentationAmount = DEFAULT_INDENTATION;
+
     /** handlers currently in use */
     private final FastStack<ExpressionHandler> mHandlers =
         FastStack.newInstance();
@@ -190,6 +194,26 @@ public class IndentationCheck extends Check
         return mCaseIndentationAmount;
     }
 
+    /**
+     * Set the throws indentation level.
+     *
+     * @param aThrowsIndent the throws indentation level
+     */
+    public void setThrowsIndent(int aThrowsIndent)
+    {
+        mThrowsIndentationAmount = aThrowsIndent;
+    }
+
+    /**
+     * Get the throws indentation level.
+     *
+     * @return the throws indentation level
+     */
+    public int getThrowsIndent()
+    {
+        return this.mThrowsIndentationAmount;
+    }
+
     /**
      * Log an error message.
      *
