@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2012  Oliver Burn
+// Copyright (C) 2001-2014  Oliver Burn
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -106,8 +106,27 @@ public class GenericWhitespaceCheck extends Check
                 }
             }
             else {
-                // In a nested Generic type, so can only be a '>' or ','
-                if ((line.charAt(after) != '>') && (line.charAt(after) != ','))
+                // In a nested Generic type, so can only be a '>' or ',' or '&'
+
+                // In case of several extends definitions:
+                //
+                //   class IntEnumValueType<E extends Enum<E> & IntEnum>
+                //                                          ^
+                //   should be whitespace if followed by & -+
+                //
+                final int indexOfAmp = line.indexOf('&', after);
+                if ((indexOfAmp != -1)
+                    && whitespaceBetween(after, indexOfAmp, line))
+                {
+                    if (indexOfAmp - after == 0) {
+                        log(aAST.getLineNo(), after, "ws.notPreceded", "&");
+                    }
+                    else if (indexOfAmp - after != 1) {
+                        log(aAST.getLineNo(), after, "ws.followed", ">");
+                    }
+                }
+                else if ((line.charAt(after) != '>')
+                         && (line.charAt(after) != ','))
                 {
                     log(aAST.getLineNo(), after, "ws.followed", ">");
                 }
@@ -158,4 +177,24 @@ public class GenericWhitespaceCheck extends Check
             log(aAST.getLineNo(), after, "ws.followed", "<");
         }
     }
+
+    /**
+     * Returns whether the specified string contains only whitespace between
+     * specified indices.
+     *
+     * @param aFromIndex the index to start the search from. Inclusive
+     * @param aToIndex the index to finish the search. Exclusive
+     * @param aLine the line to check
+     * @return whether there are only whitespaces (or nothing)
+     */
+    private static boolean whitespaceBetween(
+        int aFromIndex, int aToIndex, String aLine)
+    {
+        for (int i = aFromIndex; i < aToIndex; i++) {
+            if (!Character.isWhitespace(aLine.charAt(i))) {
+                return false;
+            }
+        }
+        return true;
+    }
 }
