@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2012  Oliver Burn
+// Copyright (C) 2001-2014  Oliver Burn
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -680,6 +680,17 @@ public class IndentationCheckTest extends BaseCheckTestSupport
         verify(checkConfig, getPath("indentation/InputUseTwoSpaces.java"), expected);
     }
 
+    @Test
+    public void testThrowsIndentationLevel() throws Exception
+    {
+        final DefaultConfiguration checkConfig = createCheckConfig(IndentationCheck.class);
+        checkConfig.addAttribute("throwsIndent", Integer.valueOf(8).toString());
+        final String[] expected = {
+            "18: method def throws at indentation level 8 not at correct indentation, 12",
+        };
+        verify(checkConfig, getPath("indentation/InvalidInputThrowsIndent.java"), expected);
+    }
+
     @Test
     public void testCaseLevel() throws Exception
     {
